#!/bin/sh
# author: deadc0de6 (https://github.com/deadc0de6)
# Copyright (c) 2017, deadc0de6

cur=$(dirname "$(readlink -f "${0}")")

# stop on first error
set -e
#set -v

# pycodestyle
echo "[+] pycodestyle"
pycodestyle --version
pycodestyle --ignore=W605 catcli/
pycodestyle tests/
pycodestyle setup.py

# pyflakes
echo "[+] pyflakes"
pyflakes --version
pyflakes catcli/
pyflakes tests/
pyflakes setup.py

# pylint
# R0914: Too many local variables
# R0913: Too many arguments
# R0912: Too many branches
# R0915: Too many statements
# R0911: Too many return statements
# R0903: Too few public methods
# R0801: Similar lines in 2 files
# R0902: Too many instance attributes
# R0201: no-self-used
echo "[+] pylint"
pylint --version
pylint -sn \
  --disable=R0914 \
  --disable=R0913 \
  --disable=R0912 \
  --disable=R0915 \
  --disable=R0911 \
  --disable=R0903 \
  --disable=R0801 \
  --disable=R0902 \
  --disable=R0201 \
  --disable=R0022 \
  catcli/
pylint -sn \
  --disable=W0212 \
  --disable=R0914 \
  --disable=R0915 \
  --disable=R0801 \
  tests/
pylint -sn setup.py

# mypy
echo "[+] mypy"
mypy \
  --strict \
  catcli/

# unittest
echo "[+] unittests"
coverage run -p -m pytest tests

# tests-ng
echo "[+] tests-ng"
for t in "${cur}"/tests-ng/*.sh; do
  echo "running test \"$(basename "${t}")\""
  ${t}
done

# check shells
echo "[+] shellcheck"
if ! which shellcheck >/dev/null 2>&1; then
  echo "Install shellcheck"
  exit 1
fi
shellcheck --version
find . -iname '*.sh' | while read -r script; do
  shellcheck -x \
    "${script}"
done

# merge coverage
echo "[+] coverage merge"
coverage combine

echo "ALL TESTS DONE OK"
exit 0
